@@ -15,6 +15,7 @@
 package apiserver
 
 import (
+	"errors"
 	"testing"
 	"time"
 
@@ -37,13 +38,13 @@ func TestApiServerSourceUpdate(t *testing.T) {
 
 	apiServerRecorder := apiServerClient.Recorder()
 
-	present := createAPIServerSource("testsource", "Event", "v1", "testsa1", "Reference", map[string]string{"bla": "blub", "foo": "bar"}, createSinkv1("svc1", "default"))
+	present := createAPIServerSource("testsource", "testsa1", "Reference", []string{"Event"}, []string{"v1"}, map[string]string{"bla": "blub", "foo": "bar"}, createSinkv1("svc1", "default"))
 	apiServerRecorder.GetAPIServerSource("testsource", present, nil)
 
-	updated := createAPIServerSource("testsource", "Event", "v1", "testsa2", "Reference", map[string]string{"foo": "baz"}, createSinkv1("svc2", "default"))
+	updated := createAPIServerSource("testsource", "testsa2", "Reference", []string{"Event", "Pod"}, []string{"v1", "v1"}, map[string]string{"foo": "baz"}, createSinkv1("svc2", "default"))
 	apiServerRecorder.UpdateAPIServerSource(updated, nil)
 
-	output, err := executeAPIServerSourceCommand(apiServerClient, dynamicClient, "update", "testsource", "--service-account", "testsa2", "--sink", "ksvc:svc2", "--ce-override", "bla-", "--ce-override", "foo=baz")
+	output, err := executeAPIServerSourceCommand(apiServerClient, dynamicClient, "update", "testsource", "--service-account", "testsa2", "--sink", "ksvc:svc2", "--ce-override", "bla-", "--ce-override", "foo=baz", "--mode", "Reference", "--resource", "Pod:v1")
 	assert.NilError(t, err)
 	assert.Assert(t, util.ContainsAll(output, "testsource", "updated", "default"))
 
@@ -54,7 +55,7 @@ func TestApiServerSourceUpdateDeletionTimestampNotNil(t *testing.T) {
 	apiServerClient := v1.NewMockKnAPIServerSourceClient(t)
 	apiServerRecorder := apiServerClient.Recorder()
 
-	present := createAPIServerSource("testsource", "Event", "v1", "testsa1", "Ref", nil, createSinkv1("svc1", "default"))
+	present := createAPIServerSource("testsource", "testsa1", "Ref", []string{"Event"}, []string{"v1"}, nil, createSinkv1("svc1", "default"))
 	present.DeletionTimestamp = &metav1.Time{Time: time.Now()}
 	apiServerRecorder.GetAPIServerSource("testsource", present, nil)
 
@@ -63,3 +64,30 @@ func TestApiServerSourceUpdateDeletionTimestampNotNil(t *testing.T) {
 	assert.ErrorContains(t, err, "deletion")
 	assert.ErrorContains(t, err, "apiserver")
 }
+
+func TestApiServerUpdateErrorForNoArgs(t *testing.T) {
+	apiServerClient := v1.NewMockKnAPIServerSourceClient(t)
+	out, err := executeAPIServerSourceCommand(apiServerClient, nil, "update")
+	assert.ErrorContains(t, err, "single argument")
+	assert.Assert(t, util.ContainsAll(out, "requires", "single argument"))
+}
+
+func TestApiServerUpdateSinkMissingError(t *testing.T) {
+	apiServerClient := v1.NewMockKnAPIServerSourceClient(t)
+	apiServerRecorder := apiServerClient.Recorder()
+
+	//check if sink is missing
+	dynamicClient := dynamicfake.CreateFakeKnDynamicClient("default", &servingv1.Service{
+		TypeMeta:   metav1.TypeMeta{Kind: "Service", APIVersion: "serving.knative.dev/v1"},
+		ObjectMeta: metav1.ObjectMeta{Name: "svc2", Namespace: "default"},
+	})
+
+	present := createAPIServerSource("testsource", "testsa1", "Reference", []string{"Event"}, []string{"v1"}, map[string]string{"bla": "blub", "foo": "bar"}, createSinkv1("svc1", "default"))
+	apiServerRecorder.GetAPIServerSource("testsource", present, nil)
+	sinkMissingMsg := "services.serving.knative.dev \"svc3\" not found"
+	apiServerRecorder.UpdateAPIServerSource("", errors.New(sinkMissingMsg))
+
+	out, err := executeAPIServerSourceCommand(apiServerClient, dynamicClient, "update", "testsource", "--service-account", "testsa2", "--sink", "ksvc:svc3", "--ce-override", "bla-", "--ce-override", "foo=baz")
+	assert.ErrorContains(t, err, "not found")
+	assert.Assert(t, util.ContainsAll(out, "services.serving.knative.dev", "svc3", "not found"))
+}
