@@ -19,17 +19,17 @@ import (
 	"testing"
 	"time"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 
 	dynamicfake "knative.dev/client/pkg/dynamic/fake"
-	clienteventingv1alpha1 "knative.dev/client/pkg/eventing/v1alpha1"
+	clienteventingv1 "knative.dev/client/pkg/eventing/v1"
 	"knative.dev/client/pkg/util"
 )
 
 func TestTriggerUpdate(t *testing.T) {
-	eventingClient := clienteventingv1alpha1.NewMockKnEventingClient(t)
+	eventingClient := clienteventingv1.NewMockKnEventingClient(t)
 	dynamicClient := dynamicfake.CreateFakeKnDynamicClient("default", &servingv1.Service{
 		TypeMeta:   metav1.TypeMeta{Kind: "Service", APIVersion: "serving.knative.dev/v1"},
 		ObjectMeta: metav1.ObjectMeta{Name: "mysvc", Namespace: "default"},
@@ -42,28 +42,28 @@ func TestTriggerUpdate(t *testing.T) {
 	eventingRecorder.UpdateTrigger(updated, nil)
 
 	out, err := executeTriggerCommand(eventingClient, dynamicClient, "update", triggerName,
-		"--filter", "type=dev.knative.new", "--sink", "svc:mysvc")
+		"--filter", "type=dev.knative.new", "--sink", "ksvc:mysvc")
 	assert.NilError(t, err, "Trigger should be updated")
-	util.ContainsAll(out, "Trigger", triggerName, "updated", "namespace", "default")
+	assert.Assert(t, util.ContainsAll(out, "Trigger", triggerName, "updated", "namespace", "default"))
 
 	eventingRecorder.Validate()
 }
 
 func TestTriggerUpdateWithError(t *testing.T) {
-	eventingClient := clienteventingv1alpha1.NewMockKnEventingClient(t)
+	eventingClient := clienteventingv1.NewMockKnEventingClient(t)
 	eventingRecorder := eventingClient.Recorder()
 	eventingRecorder.GetTrigger(triggerName, nil, fmt.Errorf("trigger not found"))
 
 	out, err := executeTriggerCommand(eventingClient, nil, "update", triggerName,
-		"--filter", "type=dev.knative.new", "--sink", "svc:newsvc")
+		"--filter", "type=dev.knative.new", "--sink", "ksvc:newsvc")
 	assert.ErrorContains(t, err, "trigger not found")
-	util.ContainsAll(out, "Usage", triggerName)
+	assert.Assert(t, util.ContainsAll(out, "Usage", triggerName))
 
 	eventingRecorder.Validate()
 }
 
 func TestTriggerUpdateInvalidBroker(t *testing.T) {
-	eventingClient := clienteventingv1alpha1.NewMockKnEventingClient(t)
+	eventingClient := clienteventingv1.NewMockKnEventingClient(t)
 	eventingRecorder := eventingClient.Recorder()
 	present := createTrigger("default", triggerName, map[string]string{"type": "dev.knative.new"}, "mybroker", "newsvc")
 	eventingRecorder.GetTrigger(triggerName, present, nil)
@@ -71,13 +71,13 @@ func TestTriggerUpdateInvalidBroker(t *testing.T) {
 	out, err := executeTriggerCommand(eventingClient, nil, "update", triggerName,
 		"--broker", "newbroker")
 	assert.ErrorContains(t, err, "broker is immutable")
-	util.ContainsAll(out, "Usage", triggerName)
+	assert.Assert(t, util.ContainsAll(out, "Usage", triggerName))
 
 	eventingRecorder.Validate()
 }
 
 func TestTriggerUpdateDeletionTimestampNotNil(t *testing.T) {
-	eventingClient := clienteventingv1alpha1.NewMockKnEventingClient(t)
+	eventingClient := clienteventingv1.NewMockKnEventingClient(t)
 
 	eventingRecorder := eventingClient.Recorder()
 	present := createTrigger("default", triggerName, map[string]string{"type": "dev.knative.foo"}, "mybroker", "mysvc")
@@ -85,7 +85,7 @@ func TestTriggerUpdateDeletionTimestampNotNil(t *testing.T) {
 	eventingRecorder.GetTrigger(triggerName, present, nil)
 
 	_, err := executeTriggerCommand(eventingClient, nil, "update", triggerName,
-		"--filter", "type=dev.knative.new", "--sink", "svc:mysvc")
+		"--filter", "type=dev.knative.new", "--sink", "ksvc:mysvc")
 	assert.ErrorContains(t, err, present.Name)
 	assert.ErrorContains(t, err, "deletion")
 	assert.ErrorContains(t, err, "trigger")
